@@ -331,6 +331,9 @@ providers_list = {
     'manganelo_com': [
         r'manganelo\.com/(manga|chapter)/.',
     ],
+    'manganelos_com': [
+        r'manganelos\.com/manga/.',
+    ],
     'mangaonline_com_br': [
         r'mangaonline\.com\.br/.',
     ],
