@@ -5,9 +5,6 @@ from .helpers.std import Std
 class InMangaCom(Provider, Std):
     __local_storage = None
 
-    def get_archive_name(self) -> str:
-        return self.normal_arc_name(self.get_chapter_index())
-
     def get_chapter_index(self) -> str:
         return str(self.chapter['Number'])
 
